metric_drop_index: Compute drop index for each row
Description
This function returns the index of the dropped column for each row, or NA if no column was dropped.
Usage
metric_drop_index(c_output)
Value
A vector of drop indices (or NA if no drop occurred).
Arguments
- c_output
A list containing output data to compute the drop index.