powered by
This function calculates the total number of section NAs for each column in the dataset.
metric_sec_na(c_output)
A vector of section NA values.
A list containing output data to compute the section NA metric.